@@ -55,13 +55,22 @@ nomagic_style <- function(srcData, ignore = c(-1, 0, 1, 2, 100),
 
     ## NUMBERS IN ASSIGNMENT EXPRESSIONS
     ##
-    ## Numbers that appear in "simple" assignments to variable with
-    ## all uppercase names are considered "not magic". Such
-    ## expressions should have few children in the parse tree and hold
-    ## on a single line of source code.
+    ## The shape of the parse tree for simple assignment expressions
+    ## is as follows:
     ##
-    ## "Simplicity" of an assignment is determined by the number of
-    ## levels of sub-expressions in the call to '<-':
+    ##             expr
+    ##    /---------|--------\
+    ## expr    LEFT_ASSIGN  expr (*)
+    ##  |                    |
+    ## SYMBOL               NUM_CONST
+    ##
+    ## Expressions involving NUM_CONST on the right hand side of
+    ## assignments have more 'expr' levels below the 'expr' marked
+    ## (*), above.
+    ##
+    ## Numbers in "simple" assignments to variables with all uppercase
+    ## names are considered "not magic". Simplicity is determined by
+    ## the number of levels of sub-expressions in the call to '<-':
     ##
     ##   M <- 32          1 level ('32')
     ##   M <- 32 - 1      2 levels ('32', '32 - 1')
@@ -71,30 +80,56 @@ nomagic_style <- function(srcData, ignore = c(-1, 0, 1, 2, 100),
     ## Set the maximum number of levels (this is a valid magic number!).
     MAXLEVELS <- 3L
 
-    ## Determine a regex pattern to identify valid assignment
-    ## expressions with '<-', '=' or '->' to names in uppercase
-    ## letters only (and the other symbols accepted in names).
-    name <- "[A-Z.][A-Z0-9_.]*"
-    pat <- paste0("(^", name, " *(<-|=))", "|", "(-> *", name, "$)")
+    ## Function to get the text of the SYMBOL token corresponding to
+    ## the id of the first child of 'expr (*)' above, be it a
+    ## NUM_CONST or an 'expr' containing a NUM_CONST.
+    getSymbolName <- function(parseData, id)
+    {
+        ## Get the id of the 'expr' parent of 'id'.
+        id.parent <- getParseParent(parseData, id)
+
+        ## Get the parse information of all the siblings of 'expr'
+        ## (this excludes 'expr' itself).
+        p <- parseData[as.character(getParseSiblings(parseData, id.parent)), ]
+
+        ## We look after the SYMBOL text if one of the siblings is an
+        ## assignment. The expression on the left hand side should
+        ## only be a symbol.
+        if (any(p$token %in% c("LEFT_ASSIGN", "RIGHT_ASSIGN")))
+        {
+            id.expr <- p$id[which(p$token == "expr")]
+            w <- which(parseData$token == "SYMBOL" & parseData$parent == id.expr)
+            if (length(w) > 0L)
+                return(parseData$text[w])
+        }
+
+        ## Return NULL in all other cases.
+        NULL
+    }
+
+    ## Function to check that the text of a symbol is a valid
+    ## identifier for a magic number, namely: containing only
+    ## uppercase letters, digits, the period and the underscore.
+    is.validName <- function(name)
+        !(is.null(name) || nzchar(gsub("[[:upper:][:digit:]_.]", "", name)))
 
     ## Starting from NUM_CONST, move up MAXLEVELS in the call stack to
     ## identify simple assignments of magic numbers to variables.
     id <- parseData$id[w]
     for (i in seq_len(MAXLEVELS))
     {
-        ## Move one level up the call stack.
-        id <- getParseParent(parseData, id)
+        ## Determine if the NUM_CONST are valid assignments of magic
+        ## numbers.
+        valid <- sapply(id,
+                        function(id) is.validName(getSymbolName(parseData, id)))
 
-        ## Get the text of the parent expression.
-        expr <- getParseText(parseData, getParseParent(parseData, id))
-
-        ## Determine if it is a valid assignment of a magic number.
-        valid <- grepl(pat, expr)
-
-        ## Remove id and position of numbers in simple assignments
-        ## from the list of potential magic numbers.
+        ## Remove id and position of valid assignments from the list
+        ## of potential magic numbers.
         id <- id[!valid]
         w <- w[!valid]
+
+        ## Move one level up the call stack.
+        id <- getParseParent(parseData, id)
     }
 
     ## Check that there are no remaining magic numbers.
